@@ -360,7 +360,7 @@ def parse_variation(p: Product, selector: parsel.Selector = None):
         values = variation.variationValues.to_dict()
         selected = variation.selected_variations.to_dict()
         variations = variation.asinVariationValues.to_dict()
-    except (js2py.internals.simplex.JsException, AttributeError):
+    except (js2py.internals.simplex.JsException, AttributeError, RuntimeError):
         p.variation_values = None
         p.selected_variations = None
         p.asin_variation_values = None
